@@ -173,7 +173,7 @@ class KafkaLogger(metaclass=SingletonMeta):
                     "className": "",
                     "sqlCost": 0,
                     "size": len(str(message)),
-                    "uid": int(trace_id) if trace_id and trace_id.isdigit() else 0
+                    "uid": int(Snowflake.next_id())  # 独立新的id
                 }
 
                 # 智能队列管理
@@ -470,12 +470,22 @@ class SYLogger:
         thread_info = SYLogger._get_execution_context()
 
         # 构建日志结构，添加线程/协程信息到threadName字段
-        request_log = {
-            "trace_id": str(trace_id) if trace_id else Snowflake.next_id(),
-            "message": msg_str,
-            "level": level,
-            "threadName": thread_info
-        }
+        request_log = {}
+        if level == "ERROR":
+            request_log = {
+                "trace_id": str(trace_id) if trace_id else Snowflake.next_id(),
+                "message": msg_str,
+                "traceback": traceback.format_exc(),
+                "level": level,
+                "threadName": thread_info
+            }
+        else:
+            request_log = {
+                "trace_id": str(trace_id) if trace_id else Snowflake.next_id(),
+                "message": msg_str,
+                "level": level,
+                "threadName": thread_info
+            }
 
         # 选择日志级别
         _log = ''
