@@ -25,7 +25,8 @@ class RabbitMQService:
     # 保存多个客户端实例
     _clients: Dict[str, RabbitMQClient] = {}
     # 保存消息处理器
-    _message_handlers: Dict[str, Callable] = {}
+    _message_handlers: Dict[str, Callable[[
+        MQMsgModel, AbstractIncomingMessage], Coroutine[Any, Any, None]]] = {}
     # 保存消费者任务
     _consumer_tasks: Dict[str, asyncio.Task] = {}
     # 保存配置信息
@@ -179,18 +180,11 @@ class RabbitMQService:
             auto_delete=kwargs.get('auto_delete', False),
             auto_parse_json=kwargs.get('auto_parse_json', True),
             create_if_not_exists=create_if_not_exists,
-            connection_timeout=kwargs.get('connection_timeout', 10),
-            rpc_timeout=kwargs.get('rpc_timeout', 10),
-            reconnection_delay=kwargs.get('reconnection_delay', 1),
-            max_reconnection_attempts=kwargs.get(
-                'max_reconnection_attempts', 5),
             prefetch_count=kwargs.get('prefetch_count', 2),
-            consumption_stall_threshold=kwargs.get(
-                'consumption_stall_threshold', 60),  # 延长停滞阈值
         )
 
-        # 使用declare_queue控制是否声明队列（发送器不声明，监听器声明）
-        await client.connect(declare_queue=not is_sender)
+        # 新客户端connect无declare_queue参数，自动根据create_if_not_exists处理
+        await client.connect()
 
         # 监听器客户端连接后延迟1秒，确保消费状态就绪（仅首次启动）
         if not is_sender and create_if_not_exists:
@@ -239,19 +233,16 @@ class RabbitMQService:
                 # 异步检查连接状态（适配新客户端的async属性）
                 if await client.is_connected:
                     # 如果是监听器但队列未初始化，重新连接
-                    if not is_sender:
-                        # 异步获取队列（适配新客户端的原子方法）
-                        _, _, queue = await client._get_connection_resources()
-                        if not queue:
-                            logger.info(f"客户端 '{client_name}' 队列未初始化，重新连接")
-                            client.create_if_not_exists = True
-                            await client.connect(force_reconnect=True, declare_queue=True)
+                    if not is_sender and not client._queue:  # 直接访问 _queue 属性
+                        logger.info(f"客户端 '{client_name}' 队列未初始化，重新连接")
+                        client.create_if_not_exists = True
+                        await client.connect()
                     return client
                 else:
                     logger.info(f"客户端 '{client_name}' 连接已关闭，重新连接")
                     if not is_sender:
                         client.create_if_not_exists = True
-                    await client.connect(declare_queue=not is_sender)
+                    await client.connect()
                     return client
 
             # 创建新客户端
@@ -267,7 +258,7 @@ class RabbitMQService:
                     app_name=cls._config.get("APP_NAME", ""),
                     **kwargs
                 )
-                await client.connect(declare_queue=False)
+                await client.connect()
                 cls._clients[client_name] = client
                 return client
 
@@ -280,7 +271,7 @@ class RabbitMQService:
                 client = await cls._create_client(
                     initial_queue_name, ** kwargs
                 )
-                await client.connect(declare_queue=True)
+                await client.connect()
                 cls._clients[client_name] = client
                 return client
 
@@ -292,16 +283,14 @@ class RabbitMQService:
             )
 
             client.create_if_not_exists = True
-            await client.connect(declare_queue=True)
+            await client.connect()
 
-            # 验证队列是否创建成功（异步获取队列）
-            _, _, queue = await client._get_connection_resources()
-            if not queue:
+            # 验证队列是否创建成功（直接访问 _queue 属性）
+            if not client._queue:
                 logger.error(f"队列 '{initial_queue_name}' 创建失败，尝试重新创建")
                 client.create_if_not_exists = True
-                await client.connect(force_reconnect=True, declare_queue=True)
-                _, _, queue = await client._get_connection_resources()
-                if not queue:
+                await client.connect()
+                if not client._queue:
                     raise Exception(f"无法创建队列 '{initial_queue_name}'")
 
             # 记录已初始化的队列
@@ -348,7 +337,7 @@ class RabbitMQService:
                 if normalized_name in cls._clients:
                     client = cls._clients[normalized_name]
                     if not await client.is_connected:
-                        await client.connect(declare_queue=False)
+                        await client.connect()
                 else:
                     client = await cls.get_client(
                         client_name=normalized_name,
@@ -537,13 +526,16 @@ class RabbitMQService:
                         # 启动消费前再次校验连接和队列状态
                         if not await client.is_connected:
                             logger.info(f"消费者 '{client_name}' 连接断开，尝试重连")
-                            await client.connect(force_reconnect=True, declare_queue=True)
+                            await client.connect()
 
-                        # 确保队列已就绪
-                        _, _, queue = await client._get_connection_resources()
-                        if not queue:
+                        # 确保队列已就绪（直接访问 _queue 属性）
+                        if not client._queue:
                             raise Exception("队列未初始化完成")
 
+                        # 确保消息处理器已设置
+                        if not client._message_handler:
+                            raise Exception("消息处理器未设置")
+
                         consumer_tag = await client.start_consuming()
                         if consumer_tag:
                             break
@@ -552,7 +544,7 @@ class RabbitMQService:
                         logger.warning(
                             f"启动消费者尝试 {attempt}/{max_attempts} 失败: {str(e)}")
                         if attempt < max_attempts:
-                            await asyncio.sleep(1)
+                            await asyncio.sleep(2)  # 延长重试间隔
 
                 if cls._is_shutdown:
                     logger.info("服务关闭中，消费者启动中止")
@@ -644,7 +636,7 @@ class RabbitMQService:
             else:
                 logger.info(f"发送器 '{queue_name}' 连接已断开，尝试重连")
                 try:
-                    await client.connect(declare_queue=False)
+                    await client.connect()
                     if await client.is_connected:
                         return client
                 except Exception as e:
@@ -662,7 +654,7 @@ class RabbitMQService:
                 else:
                     logger.info(f"发送器 '{suffixed_name}' 连接已断开，尝试重连")
                     try:
-                        await client.connect(declare_queue=False)
+                        await client.connect()
                         if await client.is_connected:
                             return client
                     except Exception as e:
@@ -698,7 +690,7 @@ class RabbitMQService:
             while retry_count < max_retry and not cls._is_shutdown:
                 try:
                     # 尝试重连，每次重试间隔1秒
-                    await sender.connect(force_reconnect=True, declare_queue=False)
+                    await sender.connect()
                     if await sender.is_connected:
                         logger.info(
                             f"发送器 '{queue_name}' 第 {retry_count + 1} 次重连成功")
@@ -733,11 +725,11 @@ class RabbitMQService:
                 topicCode=queue_name.split('.')[0] if queue_name else "",
                 msg=msg_content,
                 correlationDataId=kwargs.get(
-                    'correlationDataId', SYLogger.get_trace_id()),
+                    'correlationDataId', logger.get_trace_id()),
                 groupId=kwargs.get('groupId', ''),
                 dataKey=kwargs.get('dataKey', ""),
                 manualFlag=kwargs.get('manualFlag', False),
-                traceId=SYLogger.get_trace_id()
+                traceId=logger.get_trace_id()
             )
 
             # 构建消息头
@@ -749,7 +741,7 @@ class RabbitMQService:
                     user_name="SYSTEM",
                     request_path="",
                     req_type="SYSTEM",
-                    trace_id=SYLogger.get_trace_id(),
+                    trace_id=logger.get_trace_id(),
                 ).model_dump_json()
             }
 
@@ -775,70 +767,45 @@ class RabbitMQService:
             cls._is_shutdown = True
             logger.info("开始关闭RabbitMQ服务...")
 
-            # 发送停止信号给所有消费者
-            for client_name, event in cls._consumer_events.items():
-                event.set()
-                logger.info(f"已向消费者 '{client_name}' 发送退出信号")
-
-            # 等待消费者任务完成
-            remaining_time = max(
-                0.0, timeout - (asyncio.get_event_loop().time() - asyncio.get_event_loop().time()))
-            if remaining_time > 0 and cls._consumer_tasks:
-                try:
-                    done, pending = await asyncio.wait(
-                        list(cls._consumer_tasks.values()),
-                        timeout=remaining_time,
-                        return_when=asyncio.ALL_COMPLETED
-                    )
-
-                    # 处理超时的任务
-                    for task in pending:
-                        task_name = task.get_name()
-                        logger.warning(f"任务 '{task_name}' 关闭超时，强制取消")
-                        task.cancel()
-                        try:
-                            await task
-                        except (asyncio.CancelledError, RuntimeError):
-                            pass
-
-                except Exception as e:
-                    logger.error(f"等待消费者任务完成时出错: {str(e)}")
-
-            # 关闭所有客户端连接（适配新客户端的async close方法）
-            remaining_time = max(
-                0.0, timeout - (asyncio.get_event_loop().time() - asyncio.get_event_loop().time()))
-            if remaining_time > 0 and cls._clients:
-                client_count = len(cls._clients)
-                client_timeout = remaining_time / client_count  # 平均分配剩余时间
-
-                for name, client in cls._clients.items():
+            # 1. 停止所有消费者任务
+            for client_name, task in cls._consumer_tasks.items():
+                if not task.done():
+                    # 触发停止事件
+                    if client_name in cls._consumer_events:
+                        cls._consumer_events[client_name].set()
+                    # 取消任务
+                    task.cancel()
                     try:
-                        if await client.is_connected:
-                            await asyncio.wait_for(client.close(), timeout=client_timeout)
+                        await asyncio.wait_for(task, timeout=5.0)
+                    except asyncio.TimeoutError:
+                        logger.warning(f"消费者 '{client_name}' 关闭超时")
                     except Exception as e:
-                        logger.warning(f"关闭客户端 '{name}' 时出错: {str(e)}")
-                    logger.info(f"客户端 '{name}' 已关闭")
+                        logger.error(f"关闭消费者 '{client_name}' 失败: {str(e)}")
 
-            # 关闭连接池
+            # 2. 关闭所有客户端
+            for client in cls._clients.values():
+                try:
+                    await client.close()
+                except Exception as e:
+                    logger.error(f"关闭客户端失败: {str(e)}")
+
+            # 3. 关闭连接池
             if cls._connection_pool:
                 try:
                     await cls._connection_pool.close()
                     logger.info("RabbitMQ连接池已关闭")
                 except Exception as e:
-                    logger.warning(f"关闭连接池时出错: {str(e)}")
+                    logger.error(f"关闭连接池失败: {str(e)}")
 
-            # 清理所有状态
+            # 4. 清理状态
             cls._clients.clear()
-            cls._consumer_tasks.clear()
             cls._message_handlers.clear()
-            cls._sender_client_names.clear()
+            cls._consumer_tasks.clear()
             cls._consumer_events.clear()
             cls._consumer_tags.clear()
             cls._initialized_queues.clear()
+            cls._sender_client_names.clear()
             cls._init_locks.clear()
-            cls._has_listeners = False
-            cls._has_senders = False
-            cls._connection_pool = None
             cls._config = None
 
-            logger.info("RabbitMQ服务已完全关闭")
+            logger.info("RabbitMQService已完全关闭")
