@@ -123,15 +123,56 @@ async def feign(service_name, api_path, method='GET', params=None, headers=None,
 
 
 async def _handle_feign_response(response):
-    """处理Feign请求的响应"""
-    if response.status == 200:
-        content_type = response.headers.get('Content-Type')
-        if 'application/json' in content_type:
-            return await response.json()
+    """
+    处理Feign请求的响应，统一返回格式
+    调整逻辑：先判断状态码，再处理内容
+    - 200状态：优先识别JSON/文本，其他均按文件流（二进制）处理
+    - 非200状态：统一返回错误字典
+    """
+    try:
+        status_code = response.status
+        content_type = response.headers.get('Content-Type', '').lower()
+        response_body = None
+
+        if status_code == 200:
+            if 'application/json' in content_type:
+                response_body = await response.json()
+            elif 'text/' in content_type:
+                # 文本类型（text/plain、text/html等）：按文本读取
+                try:
+                    response_body = await response.text(encoding='utf-8')
+                except UnicodeDecodeError:
+                    # 兼容中文编码（gbk）
+                    response_body = await response.text(encoding='gbk')
+            else:
+                # 其他类型（PDF、图片、octet-stream等）：按文件流（二进制）读取
+                binary_data = await response.read()
+                SYLogger.info(
+                    f"按文件流处理响应，类型：{content_type}，大小：{len(binary_data)/1024:.2f}KB")
+                return io.BytesIO(binary_data)  # 返回BytesIO，支持read()
+            return response_body
         else:
-            content = await response.read()
-            return io.BytesIO(content)
-    else:
-        error_msg = await response.text()
-        SYLogger.error(f"nacos:请求失败，状态码: {response.status}，响应内容: {error_msg}")
+            # 非200状态：统一读取响应体（兼容文本/二进制错误信息）
+            try:
+                if 'application/json' in content_type:
+                    response_body = await response.json()
+                else:
+                    response_body = await response.text(encoding='utf-8', errors='ignore')
+            except Exception:
+                binary_data = await response.read()
+                response_body = f"非200状态，响应无法解码：{binary_data[:100].hex()}"
+
+            error_msg = f"请求失败，状态码: {status_code}，响应内容: {str(response_body)[:500]}"
+            SYLogger.error(error_msg)
+            return {
+                "success": False,
+                "code": status_code,
+                "message": error_msg,
+                "data": response_body
+            }
+
+    except Exception as e:
+        import traceback
+        error_detail = f"处理响应异常: {str(e)}\n{traceback.format_exc()}"
+        SYLogger.error(f"nacos:处理响应时出错: {error_detail}")
         return None
